==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/tcp/src/grouping/NxmOfTcpSrcBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.tcp.src.grouping;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmOfTcpSrcBuilder} instances.
 *
 * @see NxmOfTcpSrcBuilder
 *
 */
public class NxmOfTcpSrcBuilder implements Builder<NxmOfTcpSrc> {

    private Integer _mask;
    private PortNumber _port;


    Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> augmentation = Collections.emptyMap();

    public NxmOfTcpSrcBuilder() {
    }

    public NxmOfTcpSrcBuilder(NxmOfTcpSrc base) {
        this._mask = base.getMask();
        this._port = base.getPort();
        if (base instanceof NxmOfTcpSrcImpl) {
            NxmOfTcpSrcImpl impl = (NxmOfTcpSrcImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> aug =((AugmentationHolder<NxmOfTcpSrc>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public Integer getMask() {
        return _mask;
    }
    
    public PortNumber getPort() {
        return _port;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<NxmOfTcpSrc>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkMaskRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public NxmOfTcpSrcBuilder setMask(final Integer value) {
    if (value != null) {
        checkMaskRange(value);
        
    }
        this._mask = value;
        return this;
    }
    
    public NxmOfTcpSrcBuilder setPort(final PortNumber value) {
        this._port = value;
        return this;
    }
    
    public NxmOfTcpSrcBuilder addAugmentation(Class<? extends Augmentation<NxmOfTcpSrc>> augmentationType, Augmentation<NxmOfTcpSrc> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmOfTcpSrcBuilder removeAugmentation(Class<? extends Augmentation<NxmOfTcpSrc>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmOfTcpSrc build() {
        return new NxmOfTcpSrcImpl(this);
    }

    private static final class NxmOfTcpSrcImpl implements NxmOfTcpSrc {
    
        private final Integer _mask;
        private final PortNumber _port;
    
        private Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> augmentation = Collections.emptyMap();
    
        NxmOfTcpSrcImpl(NxmOfTcpSrcBuilder base) {
            this._mask = base.getMask();
            this._port = base.getPort();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxmOfTcpSrc> getImplementedInterface() {
            return NxmOfTcpSrc.class;
        }
    
        @Override
        public Integer getMask() {
            return _mask;
        }
        
        @Override
        public PortNumber getPort() {
            return _port;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<NxmOfTcpSrc>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(_port);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmOfTcpSrc.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxmOfTcpSrc other = (NxmOfTcpSrc)obj;
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (!Objects.equals(_port, other.getPort())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmOfTcpSrcImpl otherImpl = (NxmOfTcpSrcImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmOfTcpSrc");
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "_port", _port);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/tcp/src/grouping/NxmOfTcpSrcBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.tcp.src.grouping;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxmOfTcpSrcBuilder} instances.
 *
 * @see NxmOfTcpSrcBuilder
 *
 */
public class NxmOfTcpSrcBuilder implements Builder<NxmOfTcpSrc> {

    private Integer _mask;
    private PortNumber _port;


    Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> augmentation = Collections.emptyMap();

    public NxmOfTcpSrcBuilder() {
    }

    public NxmOfTcpSrcBuilder(NxmOfTcpSrc base) {
        this._mask = base.getMask();
        this._port = base.getPort();
        if (base instanceof NxmOfTcpSrcImpl) {
            NxmOfTcpSrcImpl impl = (NxmOfTcpSrcImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> aug =((AugmentationHolder<NxmOfTcpSrc>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public Integer getMask() {
        return _mask;
    }
    
    public PortNumber getPort() {
        return _port;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmOfTcpSrc>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkMaskRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public NxmOfTcpSrcBuilder setMask(final Integer value) {
    if (value != null) {
        checkMaskRange(value);
        
    }
        this._mask = value;
        return this;
    }
    
    public NxmOfTcpSrcBuilder setPort(final PortNumber value) {
        this._port = value;
        return this;
    }
    
    public NxmOfTcpSrcBuilder addAugmentation(Class<? extends Augmentation<NxmOfTcpSrc>> augmentationType, Augmentation<NxmOfTcpSrc> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmOfTcpSrcBuilder removeAugmentation(Class<? extends Augmentation<NxmOfTcpSrc>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmOfTcpSrc build() {
        return new NxmOfTcpSrcImpl(this);
    }

    private static final class NxmOfTcpSrcImpl implements NxmOfTcpSrc {
    
        private final Integer _mask;
        private final PortNumber _port;
    
        private Map<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> augmentation = Collections.emptyMap();
    
        NxmOfTcpSrcImpl(NxmOfTcpSrcBuilder base) {
            this._mask = base.getMask();
            this._port = base.getPort();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxmOfTcpSrc> getImplementedInterface() {
            return NxmOfTcpSrc.class;
        }
    
        @Override
        public Integer getMask() {
            return _mask;
        }
        
        @Override
        public PortNumber getPort() {
            return _port;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<NxmOfTcpSrc>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(_port);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmOfTcpSrc.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxmOfTcpSrc other = (NxmOfTcpSrc)obj;
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (!Objects.equals(_port, other.getPort())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmOfTcpSrcImpl otherImpl = (NxmOfTcpSrcImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmOfTcpSrc>>, Augmentation<NxmOfTcpSrc>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmOfTcpSrc");
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "_port", _port);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
